@@ -9,8 +9,6 @@ import argparse
 import sys
 from webdriver_manager.firefox import GeckoDriverManager
 from selenium.webdriver.firefox.service import Service as FirefoxService
-from selenium.webdriver.chrome.service import Service as ChromeService
-from webdriver_manager.chrome import ChromeDriverManager
 from prettytable import PrettyTable, ALL
 from typing import List
 from decimal import Decimal
@@ -53,11 +51,6 @@ args = parser.parse_args()
 
 options = FirefoxOptions()
 options.add_argument("--headless")
-
-chrome_options = webdriver.ChromeOptions()
-chrome_options.add_argument("--headless")
-chrome_options.add_argument("--disable-gpu")
-chrome_options.add_argument("--no-sandbox")
 #browser = webdriver.Firefox(executable_path="/users/krv/driver/geckodriver", options=options)
 
 ###################################################################################################################
@@ -670,11 +663,7 @@ def trends_google_play(gl, hl):
 
     print(Fore.GREEN + "* * * Виконую аналіз трендів... * * *" + Fore.WHITE)
 
-    try:
-        browser = webdriver.Firefox(service = FirefoxService(GeckoDriverManager().install()), options=options)
-    except Exception as e:
-        print ("Використовую ядро Chromium!")
-        browser = webdriver.Chrome(options=chrome_options)
+    browser = webdriver.Firefox(service = FirefoxService(GeckoDriverManager().install()), options=options)
     browser.implicitly_wait(10)
     browser.maximize_window()
 
@@ -683,7 +672,6 @@ def trends_google_play(gl, hl):
         time.sleep(1)
         browser.find_element(By.CLASS_NAME, "HWAcU").clear()
         browser.find_element(By.CLASS_NAME, "HWAcU").send_keys(char)
-        time.sleep(7)
         suggests = browser.find_elements(By.CLASS_NAME, "YVhSle")
         minus = 0
         for s in suggests:
